glimr/console/kernel
Glimr Console Kernel
Registers Glimr’s console commands and is the entry point to run your app’s custom console commands as well as Glimr’s default console commands.
NOTE: Database commands (migrate, gen) are now in driver packages:
- glimr_sqlite/console/kernel for sqlite:migrate, sqlite:gen
- glimr_postgres/console/kernel for postgres:migrate, postgres:gen
Values
pub fn commands(
connections: List(driver.Connection),
) -> List(command.Command)
Returns the list of internal Glimr framework commands. Commands are generic over ctx so they can be merged with user commands into a single unified list.
NOTE: Database commands (migrate, gen) are now in driver packages. Add them via glimr_sqlite/console/kernel or glimr_postgres/console/kernel.
pub fn run(
commands app_commands: List(command.Command),
db_connections db_connections: List(driver.Connection),
) -> Nil
Entry point for running console commands. Merges internal Glimr commands with user-defined commands into a single list. Commands receive the user’s context and can decode GlimrContext from it if needed.